@@ -1,5 +1,7 @@
 map <- read.delim("http://www.genenames.org/cgi-bin/hgnc_downloads.cgi?title=HGNC+output+data&submit=submit&hgnc_dbtag=on&col=gd_hgnc_id&col=gd_app_sym&col=gd_prev_sym&col=gd_aliases&status=Approved&status=Entry+Withdrawn&status_opt=2&where=&order_by=gd_app_sym_sort&format=text&limit=&.cgifields=&.cgifields=chr&.cgifields=status&.cgifields=hgnc_dbtag",as.is=TRUE)
 
+write.csv(map,file="extdata/genenames_org.csv", row.names=FALSE)
+
 M  <- do.call(rbind,apply(map[nchar(map[,3])>0 | nchar(map[,4])>0 ,], 1,
 function(x) {
     y <- strsplit(paste(x[3:4],collapse=", "), ", ")[[1]]
@@ -11,7 +13,8 @@ N[id,2] <- NA
 N[,1] <- gsub("~withdrawn","", N[,1])
 
 O = read.csv(system.file("extdata/mog_map.csv", package = "HGNChelper"),
-as.is=TRUE)[,2:1]
+             as.is=TRUE)[,2:1]
+O$mogrified <- toupper(O$mogrified)
 
 colnames(M) <- c("Symbol","Approved.Symbol")
 colnames(N) <- c("Symbol","Approved.Symbol")
